Subject: [bug#62582] [PATCH] gnu: rizin: Update to 0.5.2.

From: Theofilos Pechlivanis <[email-masked]>
Date: Sat, 1 Apr 2023 01:46:53 +0300

---
 gnu/packages/engineering.scm | 71 ++++++++++++++++++++++--------------
 1 file changed, 43 insertions(+), 28 deletions(-)

diff --git a/gnu/packages/engineering.scm b/gnu/packages/engineering.scm
index 18f2d024b1..a0431ed441 100644
--- a/gnu/packages/engineering.scm
+++ b/gnu/packages/engineering.scm
@@ -36,6 +36,7 @@
 ;;; Copyright © 2022 Artyom V. Poptsov <[email-masked]>
 ;;; Copyright © 2022 Maxim Cournoyer <[email-masked]>
 ;;; Copyright © 2022 Felix Gruber <[email-masked]>
+;;; Copyright © 2023 Theofilos Pechlivanis <[email-masked]>
 ;;;
 ;;; This file is part of GNU Guix.
 ;;;
@@ -4094,7 +4095,7 @@ (define-public candle
 (define-public rizin
   (package
     (name "rizin")
-    (version "0.4.1")
+    (version "0.5.2")
     (source (origin
               (method url-fetch)
               (uri (string-append
@@ -4102,36 +4103,50 @@ (define-public rizin
                     version "/rizin-src-v" version ".tar.xz"))
               (sha256
                (base32
-                "1f5zzlnr2na4hkvcwn4n9cjlk6595945vwrw89pa683qk5mrb7b6"))))
+                "18zca3iwdif200wiivm065fs0a5g520q6380205cijca7ky81avi"))))
     (build-system meson-build-system)
     (arguments
-     (list
-      #:configure-flags
-      #~(list "-Dpackager=guix"
-              (string-append "-Dpackager_version=" #$version)
-              "-Duse_sys_capstone=enabled"
-              "-Duse_sys_magic=enabled"
-              "-Duse_sys_libzip=enabled"
-              "-Duse_sys_zlib=enabled"
-              "-Duse_sys_lz4=enabled"
-              "-Duse_sys_xxhash=enabled"
-              "-Duse_sys_openssl=enabled"
-              "-Duse_sys_tree_sitter=enabled"
-              "-Duse_sys_libuv=enabled"
-              "-Duse_gpl=true")
-      #:phases
-      #~(modify-phases %standard-phases
-          (add-before 'configure 'skip-integration-tests
-            (lambda _
-              ;; Skip integration tests, which require prebuilt binaries at:
-              ;; <https://github.com/rizinorg/rizin-testbins>.
-              ;; And 2 of them are failing, reported upstream:
-              ;; <https://github.com/rizinorg/rizin/issues/2905>.
-              (substitute* "test/meson.build"
-                (("subdir\\('integration'\\)") "")))))))
+     (list #:configure-flags #~(list "-Dpackager=guix"
+                                     (string-append "-Dpackager_version="
+                                                    #$version)
+                                     "-Duse_sys_capstone=enabled"
+                                     "-Duse_sys_magic=enabled"
+                                     "-Duse_sys_libzip=enabled"
+                                     "-Duse_sys_zlib=enabled"
+                                     "-Duse_sys_lz4=enabled"
+                                     "-Duse_sys_lzma=enabled"
+                                     "-Duse_sys_xxhash=enabled"
+                                     "-Duse_sys_openssl=enabled"
+                                     "-Duse_sys_tree_sitter=enabled"
+                                     "-Duse_sys_libmspack=enabled"
+                                     "-Duse_gpl=true"
+                                     "-Duse_zlib=true"
+                                     "-Duse_lzma=true"
+                                     "-Dinstall_sigdb=false"
+                                     "-Duse_swift_demangler=true")
+           #:phases #~(modify-phases %standard-phases
+                        (add-before 'configure 'skip-integration-tests
+                          (lambda _
+                            ;; Skip integration tests, which require prebuilt binaries at:
+                            ;; <https://github.com/rizinorg/rizin-testbins>.
+                            ;; And 2 of them are failing, reported upstream:
+                            ;; <https://github.com/rizinorg/rizin/issues/2905>.
+                            ;; Also skip unit tests for the same reason.
+                            (substitute* "test/meson.build"
+                              (("subdir\\('integration'\\)")
+                               "")
+                              (("subdir\\('unit'\\)")
+                               "")))))))
     (native-inputs (list pkg-config))
-    (inputs
-     (list capstone file libuv libzip lz4 openssl tree-sitter xxhash zlib))
+    (inputs (list capstone
+                  file
+                  libzip
+                  lz4
+                  openssl
+                  tree-sitter
+                  xxhash
+                  zlib
+                  libmspack))
     (home-page "https://rizin.re")
     (synopsis "Disasm, debug, analyze and manipulate binary files")
     (description

base-commit: 47ea688fd27d0ce0c8ea5481f1f94d0ebc3e37eb
-- 
2.39.2